@@ -24,7 +24,7 @@ class DescribeComplianceRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Config', '2019-01-08', 'DescribeCompliance')
-		self.set_method('GET')
+		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
