@@ -24,7 +24,7 @@ class ListDiscoveredResourcesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Config', '2019-01-08', 'ListDiscoveredResources')
-		self.set_method('GET')
+		self.set_method('POST')
 
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -56,11 +56,6 @@ class ListDiscoveredResourcesRequest(RpcRequest):
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
-	def get_ComplianceType(self): # String
-		return self.get_query_params().get('ComplianceType')
-
-	def set_ComplianceType(self, ComplianceType):  # String
-		self.add_query_param('ComplianceType', ComplianceType)
 	def get_ResourceId(self): # String
 		return self.get_query_params().get('ResourceId')
 
